@@ -17,7 +17,7 @@ class Parser:
         self.debug = debug
 
     def parse(self, token_stream: TokenStream, context: Dict = {}):
-        matched = self.consume_next_sub_rule(NonTerminalToken("INIT"), token_stream, context)
+        matched = self.consume_next_sub_rule(NonTerminalToken("parser"), token_stream, context)
         return False if matched is None else True
 
     def parse_string(self, input: str, context: Dict = {}):
