@@ -26,9 +26,11 @@ class ExecutionContext:
     rule: ProductionRule
     tokens: List[Token]
     context: Dict
+    consumed_tokens: List
 
-    def __init__(self, parser, rule: ProductionRule, tokens: List[Token], context: Dict):
+    def __init__(self, parser, rule: ProductionRule, tokens: List[Token], context: Dict, consumed_tokens: []):
         self.parser = parser
         self.rule = rule
         self.tokens = tokens
         self.context = context
+        self.consumed_tokens = consumed_tokens
